summaryrefslogtreecommitdiff
path: root/src/lv2_instance.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/lv2_instance.h')
-rw-r--r--src/lv2_instance.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/lv2_instance.h b/src/lv2_instance.h
index a16e549..2f6ec54 100644
--- a/src/lv2_instance.h
+++ b/src/lv2_instance.h
@@ -8,24 +8,24 @@
****************************************************************************/
/*
- * This file is part of DrumGizmo.
+ * This file is part of CamSync.
*
* DrumGizmo is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* DrumGizmo is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with DrumGizmo; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
*/
-#ifndef __DRUMGIZMO_LV2_INSTANCE_H__
-#define __DRUMGIZMO_LV2_INSTANCE_H__
+#ifndef __CAMSYNC_LV2_INSTANCE_H__
+#define __CAMSYNC_LV2_INSTANCE_H__
#include <lv2/lv2plug.in/ns/lv2core/lv2.h>
#include <lv2/lv2plug.in/ns/ext/state/state.h>
@@ -34,15 +34,15 @@
#include "input_lv2.h"
#include "output_lv2.h"
-#include <drumgizmo.h>
+#include <camsync.h>
typedef struct {
InputLV2 *in;
OutputLV2 *out;
- DrumGizmo *dg;
+ CamSync *dg;
sample_t *buffer;
size_t buffer_size;
LV2_URID_Map* map;
} DGLV2;
-#endif/*__DRUMGIZMO_LV2_INSTANCE_H__*/
+#endif/*__CAMSYNC_LV2_INSTANCE_H__*/
@@ -8,24 +8,24 @@
*
- * DrumGizmo is free software; you can redistribute it and/or modify
+ * CamSync is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
@@ -8,24 +8,24 @@
* (at your option) any later version.
*
- * DrumGizmo is distributed in the hope that it will be useful,
+ * CamSync is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
@@ -8,24 +8,24 @@
*
* You should have received a copy of the GNU General Public License
- * along with DrumGizmo; if not, write to the Free Software
+ * along with CamSync; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
*/